==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAccessibleTextUpdateEvent_shell.h <==
#ifndef QACCESSIBLETEXTUPDATEEVENT_SHELL_H
#define QACCESSIBLETEXTUPDATEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtJambi/RegistryAPI>


class QAccessibleTextUpdateEvent_shell : public QAccessibleTextUpdateEvent, public QtJambiShellInterface
{
public:
    QAccessibleTextUpdateEvent_shell(QAccessibleInterface* iface0, int position1, const QString& oldText2, const QString& text3);
    QAccessibleTextUpdateEvent_shell(QObject* obj0, int position1, const QString& oldText2, const QString& text3);
    ~QAccessibleTextUpdateEvent_shell() override;

    QAccessibleInterface* accessibleInterface() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleTextUpdateEvent_access : public QAccessibleTextUpdateEvent
{
    void setOldText_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring oldText0);
    jstring oldText(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setPosition_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint position0);
    jint position(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setText_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
    jstring text(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QACCESSIBLETEXTUPDATEEVENT_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QAccessibleTextUpdateEvent_shell.h <==
#ifndef QACCESSIBLETEXTUPDATEEVENT_SHELL_H
#define QACCESSIBLETEXTUPDATEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtGui/qaccessible_base.h>
#include <QtJambi/RegistryAPI>


class QAccessibleTextUpdateEvent_shell : public QAccessibleTextUpdateEvent, public QtJambiShellInterface
{
public:
    QAccessibleTextUpdateEvent_shell(QAccessibleInterface* iface0, int position1, const QString& oldText2, const QString& text3);
    QAccessibleTextUpdateEvent_shell(QObject* obj0, int position1, const QString& oldText2, const QString& text3);
    ~QAccessibleTextUpdateEvent_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAccessibleTextUpdateEvent_oshell;
};


class QAccessibleTextUpdateEvent_oshell : public QAccessibleTextUpdateEvent_shell
{
public:
    using QAccessibleTextUpdateEvent_shell::QAccessibleTextUpdateEvent_shell;
    QAccessibleInterface* accessibleInterface() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleTextUpdateEvent_access : public QAccessibleTextUpdateEvent
{
    void setOldText_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring oldText0);
    jstring oldText(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setPosition_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint position0);
    jint position(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setText_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
    jstring text(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QACCESSIBLETEXTUPDATEEVENT_SHELL_H
